### GenomicsDB Protocol buffers for Python

[GenomicsDB](https://github.com/GenomicsDB/GenomicsDB/) python bindings for [protocol definitions](https://github.com/GenomicsDB/GenomicsDB/tree/master/src/resources).
